@@ -1,4 +1,3 @@
-/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 /*
  * Almanah
  * Copyright (C) Philip Withnall 2011 <philip@tecnocode.co.uk>
@@ -19,22 +18,22 @@
 
 #include <config.h>
 
-#include <stdlib.h>
+#include <gio/gio.h>
 #include <glib.h>
 #include <glib/gi18n.h>
-#include <gio/gio.h>
 #include <gtk/gtk.h>
 #include <locale.h>
+#include <stdlib.h>
 
 #include "application.h"
 #include "event-manager.h"
 #include "import-export-dialog.h"
+#include "interface.h"
 #include "main-window.h"
 #include "preferences-dialog.h"
 #include "printing.h"
 #include "search-dialog.h"
 #include "storage-manager.h"
-#include "interface.h"
 
 static void constructed (GObject *object);
 static void dispose (GObject *object);
@@ -57,7 +56,7 @@ static void action_quit_cb (GSimpleAction *action, GVariant *parameter, gpointer
 /* Some callbacks */
 void almanah_application_style_provider_parsing_error_cb (GtkCssProvider *provider, GtkCssSection *section, GError *error, gpointer user_data);
 
-struct _AlmanahApplicationPrivate {
+typedef struct {
 	gboolean debug;
 
 	GSettings *settings;
@@ -68,6 +67,10 @@ struct _AlmanahApplicationPrivate {
 
 	GtkPrintSettings *print_settings;
 	GtkPageSetup *page_setup;
+} AlmanahApplicationPrivate;
+
+struct _AlmanahApplication {
+	GtkApplication parent_instance;
 };
 
 enum {
@@ -75,16 +78,16 @@ enum {
 };
 
 static GActionEntry app_entries[] = {
-	{"search", action_search_cb, NULL, NULL, NULL},
-	{"preferences", action_preferences_cb, NULL, NULL, NULL },
-	{"import", action_import_cb, NULL, NULL, NULL },
-	{"export", action_export_cb, NULL, NULL, NULL },
-	{"print", action_print_cb, NULL, NULL, NULL },
-	{"about", action_about_cb, NULL, NULL, NULL },
-	{"quit", action_quit_cb, NULL, NULL, NULL },
+	{ "search", action_search_cb, NULL, NULL, NULL },
+	{ "preferences", action_preferences_cb, NULL, NULL, NULL },
+	{ "import", action_import_cb, NULL, NULL, NULL },
+	{ "export", action_export_cb, NULL, NULL, NULL },
+	{ "print", action_print_cb, NULL, NULL, NULL },
+	{ "about", action_about_cb, NULL, NULL, NULL },
+	{ "quit", action_quit_cb, NULL, NULL, NULL },
 };
 
-G_DEFINE_TYPE (AlmanahApplication, almanah_application, GTK_TYPE_APPLICATION)
+G_DEFINE_TYPE_WITH_PRIVATE (AlmanahApplication, almanah_application, GTK_TYPE_APPLICATION)
 
 static void
 almanah_application_class_init (AlmanahApplicationClass *klass)
@@ -93,8 +96,6 @@ almanah_application_class_init (AlmanahApplicationClass *klass)
 	GApplicationClass *gapplication_class = G_APPLICATION_CLASS (klass);
 	GtkApplicationClass *gtkapplication_class = GTK_APPLICATION_CLASS (klass);
 
-	g_type_class_add_private (klass, sizeof (AlmanahApplicationPrivate));
-
 	gobject_class->constructed = constructed;
 	gobject_class->dispose = dispose;
 	gobject_class->get_property = get_property;
@@ -115,14 +116,14 @@ almanah_application_class_init (AlmanahApplicationClass *klass)
 static void
 almanah_application_init (AlmanahApplication *self)
 {
-	self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, ALMANAH_TYPE_APPLICATION, AlmanahApplicationPrivate);
-	self->priv->debug = FALSE;
+	AlmanahApplicationPrivate *priv = almanah_application_get_instance_private (self);
+	priv->debug = FALSE;
 }
 
 static void
 constructed (GObject *object)
 {
-	AlmanahApplicationPrivate *priv = ALMANAH_APPLICATION (object)->priv;
+	AlmanahApplicationPrivate *priv = almanah_application_get_instance_private (ALMANAH_APPLICATION (object));
 
 	/* Set various properties up */
 	g_application_set_application_id (G_APPLICATION (object), "org.gnome.Almanah");
@@ -134,15 +135,15 @@ constructed (GObject *object)
 	textdomain (GETTEXT_PACKAGE);
 
 	const GOptionEntry options[] = {
-		{ "debug", 0, 0, G_OPTION_ARG_NONE, &(priv->debug), N_("Enable debug mode"), NULL },
+		{ "debug", 0, 0, G_OPTION_ARG_NONE, &(priv->debug), N_ ("Enable debug mode"), NULL },
 		{ NULL }
 	};
 
 	g_application_add_main_option_entries (G_APPLICATION (object), options);
 	g_application_set_option_context_summary (G_APPLICATION (object),
-	                                          _("Manage your diary. Only one instance of the program may be open at any time."));
+	                                          _ ("Manage your diary. Only one instance of the program may be open at any time."));
 
-	g_set_application_name (_("Almanah Diary"));
+	g_set_application_name (_ ("Almanah Diary"));
 	g_set_prgname ("org.gnome.Almanah");
 	gtk_window_set_default_icon_name ("org.gnome.Almanah");
 
@@ -153,7 +154,7 @@ constructed (GObject *object)
 static void
 dispose (GObject *object)
 {
-	AlmanahApplicationPrivate *priv = ALMANAH_APPLICATION (object)->priv;
+	AlmanahApplicationPrivate *priv = almanah_application_get_instance_private (ALMANAH_APPLICATION (object));
 
 	if (priv->main_window != NULL)
 		gtk_widget_destroy (GTK_WIDGET (priv->main_window));
@@ -186,7 +187,7 @@ dispose (GObject *object)
 static void
 get_property (GObject *object, guint property_id, GValue *value, GParamSpec *pspec)
 {
-	AlmanahApplicationPrivate *priv = ALMANAH_APPLICATION (object)->priv;
+	AlmanahApplicationPrivate *priv = almanah_application_get_instance_private (ALMANAH_APPLICATION (object));
 
 	switch (property_id) {
 		case PROP_DEBUG:
@@ -202,7 +203,7 @@ get_property (GObject *object, guint property_id, GValue *value, GParamSpec *psp
 static void
 set_property (GObject *object, guint property_id, const GValue *value, GParamSpec *pspec)
 {
-	AlmanahApplicationPrivate *priv = ALMANAH_APPLICATION (object)->priv;
+	AlmanahApplicationPrivate *priv = almanah_application_get_instance_private (ALMANAH_APPLICATION (object));
 
 	switch (property_id) {
 		case PROP_DEBUG:
@@ -218,8 +219,10 @@ set_property (GObject *object, guint property_id, const GValue *value, GParamSpe
 static void
 debug_handler (const char *log_domain, GLogLevelFlags log_level, const char *message, AlmanahApplication *self)
 {
+	AlmanahApplicationPrivate *priv = almanah_application_get_instance_private (self);
+
 	/* Only display debug messages if we've been run with --debug */
-	if (self->priv->debug == TRUE) {
+	if (priv->debug == TRUE) {
 		g_log_default_handler (log_domain, log_level, message, NULL);
 	}
 }
@@ -239,10 +242,10 @@ add_accelerator (GtkApplication *app, const gchar *action_name, const gchar *acc
 static void
 startup (GApplication *application)
 {
-	AlmanahApplicationPrivate *priv = ALMANAH_APPLICATION (application)->priv;
-	gchar *db_filename;
+	AlmanahApplicationPrivate *priv = almanah_application_get_instance_private (ALMANAH_APPLICATION (application));
+	g_autofree gchar *db_filename = NULL;
 	GError *error = NULL;
-	GtkCssProvider *style_provider;
+	g_autoptr (GtkCssProvider) style_provider = NULL;
 
 	/* Chain up. */
 	G_APPLICATION_CLASS (almanah_application_parent_class)->startup (application);
@@ -261,11 +264,10 @@ startup (GApplication *application)
 	/* Open the DB */
 	db_filename = g_build_filename (g_get_user_data_dir (), "diary.db", NULL);
 	priv->storage_manager = almanah_storage_manager_new (db_filename, priv->settings);
-	g_free (db_filename);
 
 	if (almanah_storage_manager_connect (priv->storage_manager, &error) == FALSE) {
 		GtkWidget *dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
-		                                            _("Error opening database"));
+		                                            _ ("Error opening database"));
 		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), "%s", error->message);
 		gtk_dialog_run (GTK_DIALOG (dialog));
 		gtk_widget_destroy (dialog);
@@ -282,7 +284,7 @@ startup (GApplication *application)
 
 #ifdef GTK_PRINT_SETTINGS_OUTPUT_BASENAME
 	/* Translators: This is the default name of the PDF/PS/SVG file the diary is printed to if "Print to File" is chosen. */
-	gtk_print_settings_set (priv->print_settings, GTK_PRINT_SETTINGS_OUTPUT_BASENAME, _("Diary"));
+	gtk_print_settings_set (priv->print_settings, GTK_PRINT_SETTINGS_OUTPUT_BASENAME, _ ("Diary"));
 #endif
 
 	priv->page_setup = gtk_page_setup_new ();
@@ -295,20 +297,19 @@ startup (GApplication *application)
 	g_signal_connect (G_OBJECT (style_provider), "parsing-error", G_CALLBACK (almanah_application_style_provider_parsing_error_cb), NULL);
 	gtk_css_provider_load_from_resource (style_provider, "/org/gnome/Almanah/css/almanah.css");
 	gtk_style_context_add_provider_for_screen (gdk_screen_get_default (), GTK_STYLE_PROVIDER (style_provider), GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
-	g_object_unref (style_provider);
 
 	/* Shortcuts */
-	add_accelerator(GTK_APPLICATION (application), "app.quit", "<Primary>Q");
-	add_accelerator(GTK_APPLICATION (application), "app.search", "<Primary>F");
-	add_accelerator(GTK_APPLICATION (application), "win.select-date", "<Primary>D");
-	add_accelerator(GTK_APPLICATION (application), "win.bold", "<Primary>B");
-	add_accelerator(GTK_APPLICATION (application), "win.italic", "<Primary>I");
-	add_accelerator(GTK_APPLICATION (application), "win.underline", "<Primary>U");
-	add_accelerator(GTK_APPLICATION (application), "win.hyperlink", "<Primary>H");
-	add_accelerator(GTK_APPLICATION (application), "win.insert-time", "<Primary>T");
-	add_accelerator(GTK_APPLICATION (application), "win.important", "<Primary>M");
-	add_accelerator(GTK_APPLICATION (application), "win.undo", "<Primary>Z");
-	add_accelerator(GTK_APPLICATION (application), "win.redo", "<Primary><Shift>Z");
+	add_accelerator (GTK_APPLICATION (application), "app.quit", "<Primary>Q");
+	add_accelerator (GTK_APPLICATION (application), "app.search", "<Primary>F");
+	add_accelerator (GTK_APPLICATION (application), "win.select-date", "<Primary>D");
+	add_accelerator (GTK_APPLICATION (application), "win.bold", "<Primary>B");
+	add_accelerator (GTK_APPLICATION (application), "win.italic", "<Primary>I");
+	add_accelerator (GTK_APPLICATION (application), "win.underline", "<Primary>U");
+	add_accelerator (GTK_APPLICATION (application), "win.hyperlink", "<Primary>H");
+	add_accelerator (GTK_APPLICATION (application), "win.insert-time", "<Primary>T");
+	add_accelerator (GTK_APPLICATION (application), "win.important", "<Primary>M");
+	add_accelerator (GTK_APPLICATION (application), "win.undo", "<Primary>Z");
+	add_accelerator (GTK_APPLICATION (application), "win.redo", "<Primary><Shift>Z");
 }
 
 /* Nullify our pointer to the main window when it gets destroyed (e.g. when we quit) so that we don't then try
@@ -316,14 +317,16 @@ startup (GApplication *application)
 static void
 main_window_destroy_cb (AlmanahMainWindow *main_window, AlmanahApplication *self)
 {
-	self->priv->main_window = NULL;
+	AlmanahApplicationPrivate *priv = almanah_application_get_instance_private (self);
+
+	priv->main_window = NULL;
 }
 
 static void
 activate (GApplication *application)
 {
 	AlmanahApplication *self = ALMANAH_APPLICATION (application);
-	AlmanahApplicationPrivate *priv = self->priv;
+	AlmanahApplicationPrivate *priv = almanah_application_get_instance_private (self);
 
 	/* Create the interface */
 	if (priv->main_window == NULL) {
@@ -341,7 +344,7 @@ storage_manager_disconnected_cb (__attribute__ ((unused)) AlmanahStorageManager
 {
 	if (gpgme_error_message != NULL || warning_message != NULL) {
 		GtkWidget *dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
-		                                            _("Error encrypting database"));
+		                                            _ ("Error encrypting database"));
 
 		if (gpgme_error_message != NULL && warning_message != NULL)
 			gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), "%s %s", warning_message, gpgme_error_message);
@@ -375,7 +378,7 @@ window_removed (GtkApplication *application, GtkWindow *window)
 	   from the database, allowing the encryption if necessary, we remove this reference with g_application_release.
 	   See: https://bugzilla.gnome.org/show_bug.cgi?id=695117 */
 	if (ALMANAH_IS_MAIN_WINDOW (window)) {
-		AlmanahApplicationPrivate *priv = ALMANAH_APPLICATION (application)->priv;
+		AlmanahApplicationPrivate *priv = almanah_application_get_instance_private (ALMANAH_APPLICATION (application));
 
 		g_application_hold (G_APPLICATION (application));
 
@@ -389,12 +392,12 @@ window_removed (GtkApplication *application, GtkWindow *window)
 static void
 action_search_cb (GSimpleAction *action, GVariant *parameter, gpointer user_data)
 {
-	AlmanahApplication *application;
+	AlmanahApplication *application = ALMANAH_APPLICATION (user_data);
+	AlmanahApplicationPrivate *priv = almanah_application_get_instance_private (application);
 	AlmanahSearchDialog *dialog = almanah_search_dialog_new ();
 
-	application = ALMANAH_APPLICATION (user_data);
 	gtk_window_set_application (GTK_WINDOW (dialog), GTK_APPLICATION (application));
-	gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (application->priv->main_window));
+	gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (priv->main_window));
 	gtk_widget_show (GTK_WIDGET (dialog));
 	gtk_dialog_run (GTK_DIALOG (dialog));
 
@@ -404,15 +407,13 @@ action_search_cb (GSimpleAction *action, GVariant *parameter, gpointer user_data
 static void
 action_preferences_cb (GSimpleAction *action, GVariant *parameter, gpointer user_data)
 {
-	AlmanahApplication *application;
-	GSettings *settings;
+	AlmanahApplication *application = ALMANAH_APPLICATION (user_data);
+	AlmanahApplicationPrivate *priv = almanah_application_get_instance_private (application);
+	g_autoptr (GSettings) settings = NULL;
 	AlmanahPreferencesDialog *dialog;
-
-	application = ALMANAH_APPLICATION (user_data);
 	settings = almanah_application_dup_settings (application);
 	dialog = almanah_preferences_dialog_new (settings);
-	gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (application->priv->main_window));
-	g_object_unref (settings);
+	gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (priv->main_window));
 
 	gtk_widget_show_all (GTK_WIDGET (dialog));
 	gtk_dialog_run (GTK_DIALOG (dialog));
@@ -423,16 +424,15 @@ action_preferences_cb (GSimpleAction *action, GVariant *parameter, gpointer user
 static void
 action_import_cb (GSimpleAction *action, GVariant *parameter, gpointer user_data)
 {
-	AlmanahApplication *application;
-	AlmanahStorageManager *storage_manager;
+	AlmanahApplication *application = ALMANAH_APPLICATION (user_data);
+	AlmanahApplicationPrivate *priv = almanah_application_get_instance_private (application);
+	g_autoptr (AlmanahStorageManager) storage_manager = NULL;
 	GtkWidget *dialog;
 
-	application = ALMANAH_APPLICATION (user_data);
 	storage_manager = almanah_application_dup_storage_manager (application);
 	dialog = GTK_WIDGET (almanah_import_export_dialog_new (storage_manager, TRUE));
-	g_object_unref (storage_manager);
 
-	gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (application->priv->main_window));
+	gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (priv->main_window));
 	gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
 
 	/* The dialog destroys itself once done */
@@ -442,16 +442,15 @@ action_import_cb (GSimpleAction *action, GVariant *parameter, gpointer user_data
 static void
 action_export_cb (GSimpleAction *action, GVariant *parameter, gpointer user_data)
 {
-	AlmanahApplication *application;
-	AlmanahStorageManager *storage_manager;
+	AlmanahApplication *application = ALMANAH_APPLICATION (user_data);
+	AlmanahApplicationPrivate *priv = almanah_application_get_instance_private (application);
+	g_autoptr (AlmanahStorageManager) storage_manager = NULL;
 	GtkWidget *dialog;
 
-	application = ALMANAH_APPLICATION (user_data);
 	storage_manager = almanah_application_dup_storage_manager (application);
 	dialog = GTK_WIDGET (almanah_import_export_dialog_new (storage_manager, FALSE));
-	g_object_unref (storage_manager);
 
-	gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (application->priv->main_window));
+	gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (priv->main_window));
 	gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
 
 	/* The dialog destroys itself once done */
@@ -461,71 +460,68 @@ action_export_cb (GSimpleAction *action, GVariant *parameter, gpointer user_data
 static void
 action_print_cb (GSimpleAction *action, GVariant *parameter, gpointer user_data)
 {
-	AlmanahApplication *application;
-	AlmanahStorageManager *storage_manager;
+	AlmanahApplication *application = ALMANAH_APPLICATION (user_data);
+	AlmanahApplicationPrivate *priv = almanah_application_get_instance_private (application);
+	g_autoptr (AlmanahStorageManager) storage_manager = NULL;
 
-	application = ALMANAH_APPLICATION (user_data);
 	storage_manager = almanah_application_dup_storage_manager (application);
-	almanah_print_entries (FALSE, GTK_WINDOW (application->priv->main_window), &(application->priv->page_setup), &(application->priv->print_settings), storage_manager);
-	g_object_unref (storage_manager);
+	almanah_print_entries (FALSE, GTK_WINDOW (priv->main_window), &(priv->page_setup), &(priv->print_settings), storage_manager);
 }
 
 static void
 action_about_cb (GSimpleAction *action, GVariant *parameter, gpointer user_data)
 {
-	AlmanahApplication *application;
-	AlmanahStorageManager *storage_manager;
+	AlmanahApplication *application = ALMANAH_APPLICATION (user_data);
+	AlmanahApplicationPrivate *priv = almanah_application_get_instance_private (application);
+	g_autoptr (AlmanahStorageManager) storage_manager = NULL;
 	gchar *license, *description;
 	guint entry_count;
 
-	const gchar *authors[] =
-	{
+	const gchar *authors[] = {
 		"Philip Withnall <philip@tecnocode.co.uk>",
 		NULL
 	};
 	const gchar *license_parts[] = {
-		N_("Almanah is free software: you can redistribute it and/or modify "
-		   "it under the terms of the GNU General Public License as published by "
-		   "the Free Software Foundation, either version 3 of the License, or "
-		   "(at your option) any later version."),
-		N_("Almanah is distributed in the hope that it will be useful, "
-		   "but WITHOUT ANY WARRANTY; without even the implied warranty of "
-		   "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the "
-		   "GNU General Public License for more details."),
-		N_("You should have received a copy of the GNU General Public License "
-		   "along with Almanah.  If not, see <http://www.gnu.org/licenses/>."),
+		N_ ("Almanah is free software: you can redistribute it and/or modify "
+		    "it under the terms of the GNU General Public License as published by "
+		    "the Free Software Foundation, either version 3 of the License, or "
+		    "(at your option) any later version."),
+		N_ ("Almanah is distributed in the hope that it will be useful, "
+		    "but WITHOUT ANY WARRANTY; without even the implied warranty of "
+		    "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the "
+		    "GNU General Public License for more details."),
+		N_ ("You should have received a copy of the GNU General Public License "
+		    "along with Almanah.  If not, see <http://www.gnu.org/licenses/>."),
 	};
 
 	license = g_strjoin ("\n\n",
-			  _(license_parts[0]),
-			  _(license_parts[1]),
-			  _(license_parts[2]),
-			  NULL);
+	                     _ (license_parts[0]),
+	                     _ (license_parts[1]),
+	                     _ (license_parts[2]),
+	                     NULL);
 
-	application = ALMANAH_APPLICATION (user_data);
 	storage_manager = almanah_application_dup_storage_manager (application);
 	almanah_storage_manager_get_statistics (storage_manager, &entry_count);
-	g_object_unref (storage_manager);
 
-	description = g_strdup_printf (_("A helpful diary keeper, storing %u entries."), entry_count);
+	description = g_strdup_printf (_ ("A helpful diary keeper, storing %u entries."), entry_count);
 
-	gtk_show_about_dialog (GTK_WINDOW (application->priv->main_window),
-				"version", VERSION,
-				"copyright", _("Copyright \xc2\xa9 2008-2009 Philip Withnall"),
-				"comments", description,
-				"authors", authors,
-				/* Translators: please include your names here to be credited for your hard work!
-				 * Format:
-				 * "Translator name 1 <translator@email.address>\n"
-				 * "Translator name 2 <translator2@email.address>"
-				 */
-				"translator-credits", _("translator-credits"),
-				"logo-icon-name", "org.gnome.Almanah",
-				"license", license,
-				"wrap-license", TRUE,
-				"website-label", _("Almanah Website"),
-				"website", PACKAGE_URL,
-				NULL);
+	gtk_show_about_dialog (GTK_WINDOW (priv->main_window),
+	                       "version", VERSION,
+	                       "copyright", _ ("Copyright \xc2\xa9 2008-2009 Philip Withnall"),
+	                       "comments", description,
+	                       "authors", authors,
+	                       /* Translators: please include your names here to be credited for your hard work!
+	                        * Format:
+	                        * "Translator name 1 <translator@email.address>\n"
+	                        * "Translator name 2 <translator2@email.address>"
+	                        */
+	                       "translator-credits", _ ("translator-credits"),
+	                       "logo-icon-name", "org.gnome.Almanah",
+	                       "license", license,
+	                       "wrap-license", TRUE,
+	                       "website-label", _ ("Almanah Website"),
+	                       "website", PACKAGE_URL,
+	                       NULL);
 
 	g_free (license);
 	g_free (description);
@@ -534,9 +530,9 @@ action_about_cb (GSimpleAction *action, GVariant *parameter, gpointer user_data)
 static void
 action_quit_cb (GSimpleAction *action, GVariant *parameter, gpointer user_data)
 {
-	AlmanahMainWindow *main_window;
-
-	main_window = ALMANAH_APPLICATION (user_data)->priv->main_window;
+	AlmanahApplication *application = ALMANAH_APPLICATION (user_data);
+	AlmanahApplicationPrivate *priv = almanah_application_get_instance_private (application);
+	AlmanahMainWindow *main_window = priv->main_window;
 
 	/* Hide the window to make things look faster */
 	gtk_widget_hide (GTK_WIDGET (main_window));
@@ -547,11 +543,11 @@ action_quit_cb (GSimpleAction *action, GVariant *parameter, gpointer user_data)
 
 void
 almanah_application_style_provider_parsing_error_cb (__attribute__ ((unused)) GtkCssProvider *provider,
-						     __attribute__ ((unused)) GtkCssSection  *section,
-						     GError         *error,
-						     __attribute__ ((unused)) gpointer        user_data)
+                                                     __attribute__ ((unused)) GtkCssSection *section,
+                                                     GError *error,
+                                                     __attribute__ ((unused)) gpointer user_data)
 {
-	g_warning (_("Couldn't load the CSS resources. The interface might not be styled correctly: %s"), error->message);
+	g_warning (_ ("Couldn't load the CSS resources. The interface might not be styled correctly: %s"), error->message);
 }
 
 AlmanahApplication *
@@ -564,26 +560,38 @@ gboolean
 almanah_application_get_debug (AlmanahApplication *self)
 {
 	g_return_val_if_fail (ALMANAH_IS_APPLICATION (self), FALSE);
-	return self->priv->debug;
+
+	AlmanahApplicationPrivate *priv = almanah_application_get_instance_private (self);
+
+	return priv->debug;
 }
 
 AlmanahEventManager *
 almanah_application_dup_event_manager (AlmanahApplication *self)
 {
 	g_return_val_if_fail (ALMANAH_IS_APPLICATION (self), NULL);
-	return g_object_ref (self->priv->event_manager);
+
+	AlmanahApplicationPrivate *priv = almanah_application_get_instance_private (self);
+
+	return g_object_ref (priv->event_manager);
 }
 
 AlmanahStorageManager *
 almanah_application_dup_storage_manager (AlmanahApplication *self)
 {
 	g_return_val_if_fail (ALMANAH_IS_APPLICATION (self), NULL);
-	return g_object_ref (self->priv->storage_manager);
+
+	AlmanahApplicationPrivate *priv = almanah_application_get_instance_private (self);
+
+	return g_object_ref (priv->storage_manager);
 }
 
 GSettings *
 almanah_application_dup_settings (AlmanahApplication *self)
 {
 	g_return_val_if_fail (ALMANAH_IS_APPLICATION (self), NULL);
-	return g_object_ref (self->priv->settings);
+
+	AlmanahApplicationPrivate *priv = almanah_application_get_instance_private (self);
+
+	return g_object_ref (priv->settings);
 }
