@@ -1,8 +1,7 @@
-/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 /*
  * Almanah
  * Copyright (C) Philip Withnall 2008, 2009, 2011 <philip@tecnocode.co.uk>
- * 
+ *
  * Almanah is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -18,8 +17,8 @@
  */
 
 #include <config.h>
-#include <glib.h>
 #include <gio/gio.h>
+#include <glib.h>
 #include <gtksourceview/gtksource.h>
 
 #include "application.h"
@@ -27,18 +26,13 @@
 int
 main (int argc, char *argv[])
 {
-	AlmanahApplication *application;
+	g_autoptr (AlmanahApplication) application = NULL;
 	int status;
 
-#if !GLIB_CHECK_VERSION (2, 31, 0)
-	g_thread_init (NULL);
-#endif
-
 	gtk_source_init ();
 
 	application = almanah_application_new ();
 	status = g_application_run (G_APPLICATION (application), argc, argv);
-	g_object_unref (application);
 
 	gtk_source_finalize ();
 
